Class: GOBL::Bill::Ordering
- Defined in:
- lib/generated/gobl/bill/ordering.rb
Overview
Ordering provides additional information about the ordering process including references to other documents and alternative parties involved in the order-to-delivery process.
Constant Summary collapse
- SCHEMA_ID =
The Schema ID of the GOBL Ordering structure
'https://gobl.org/draft-0/bill/ordering'
Instance Attribute Summary collapse
-
#buyer ⇒ GOBL::Org::Party
readonly
Party who is responsible for issuing payment, if not the same as the customer.
-
#code ⇒ GOBL::CBC::Code
readonly
Identifier assigned by the customer or buyer for internal routing purposes.
-
#contracts ⇒ Array<GOBL::Org::DocumentRef>
readonly
The identification of contracts.
-
#cost ⇒ GOBL::CBC::Code
readonly
Buyer accounting reference cost code associated with the document.
-
#despatch ⇒ Array<GOBL::Org::DocumentRef>
readonly
Despatch advice.
-
#identities ⇒ Array<GOBL::Org::Identity>
readonly
Any additional Codes, IDs, SKUs, or other regional or custom identifiers that may be used to identify the order.
-
#issuer ⇒ GOBL::Org::Party
readonly
Issuer represents a third party responsible for issuing the invoice, but is not responsible for tax.
-
#period ⇒ GOBL::Cal::Period
readonly
Period of time that the invoice document refers to often used in addition to the details provided in the individual line items.
-
#projects ⇒ Array<GOBL::Org::DocumentRef>
readonly
Projects this invoice refers to.
-
#purchases ⇒ Array<GOBL::Org::DocumentRef>
readonly
Purchase orders issued by the customer or buyer.
-
#receiving ⇒ Array<GOBL::Org::DocumentRef>
readonly
Receiving Advice.
-
#sales ⇒ Array<GOBL::Org::DocumentRef>
readonly
Sales orders issued by the supplier or seller.
-
#seller ⇒ GOBL::Org::Party
readonly
Seller is the party liable to pay taxes on the transaction if not the same as the supplier.
-
#tender ⇒ Array<GOBL::Org::DocumentRef>
readonly
Tender advice, the identification of the call for tender or lot the invoice relates to.
Method Summary
Methods inherited from Object
Methods inherited from Struct
#as_json, from_data, from_json!, #to_json
Instance Attribute Details
#buyer ⇒ GOBL::Org::Party (readonly)
Party who is responsible for issuing payment, if not the same as the customer.
38 |
# File 'lib/generated/gobl/bill/ordering.rb', line 38 property :buyer, GOBL::Org::Party |
#code ⇒ GOBL::CBC::Code (readonly)
Identifier assigned by the customer or buyer for internal routing purposes.
18 |
# File 'lib/generated/gobl/bill/ordering.rb', line 18 property :code, GOBL::CBC::Code |
#contracts ⇒ Array<GOBL::Org::DocumentRef> (readonly)
The identification of contracts.
58 |
# File 'lib/generated/gobl/bill/ordering.rb', line 58 property :contracts, [GOBL::Org::DocumentRef] |
#cost ⇒ GOBL::CBC::Code (readonly)
Buyer accounting reference cost code associated with the document.
28 |
# File 'lib/generated/gobl/bill/ordering.rb', line 28 property :cost, GOBL::CBC::Code |
#despatch ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Despatch advice.
78 |
# File 'lib/generated/gobl/bill/ordering.rb', line 78 property :despatch, [GOBL::Org::DocumentRef] |
#identities ⇒ Array<GOBL::Org::Identity> (readonly)
Any additional Codes, IDs, SKUs, or other regional or custom identifiers that may be used to identify the order.
23 |
# File 'lib/generated/gobl/bill/ordering.rb', line 23 property :identities, [GOBL::Org::Identity] |
#issuer ⇒ GOBL::Org::Party (readonly)
Issuer represents a third party responsible for issuing the invoice, but is not responsible for tax. Some tax regimes and formats require this field.
48 |
# File 'lib/generated/gobl/bill/ordering.rb', line 48 property :issuer, GOBL::Org::Party |
#period ⇒ GOBL::Cal::Period (readonly)
Period of time that the invoice document refers to often used in addition to the details provided in the individual line items.
33 |
# File 'lib/generated/gobl/bill/ordering.rb', line 33 property :period, GOBL::Cal::Period |
#projects ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Projects this invoice refers to.
53 |
# File 'lib/generated/gobl/bill/ordering.rb', line 53 property :projects, [GOBL::Org::DocumentRef] |
#purchases ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Purchase orders issued by the customer or buyer.
63 |
# File 'lib/generated/gobl/bill/ordering.rb', line 63 property :purchases, [GOBL::Org::DocumentRef] |
#receiving ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Receiving Advice.
73 |
# File 'lib/generated/gobl/bill/ordering.rb', line 73 property :receiving, [GOBL::Org::DocumentRef] |
#sales ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Sales orders issued by the supplier or seller.
68 |
# File 'lib/generated/gobl/bill/ordering.rb', line 68 property :sales, [GOBL::Org::DocumentRef] |
#seller ⇒ GOBL::Org::Party (readonly)
Seller is the party liable to pay taxes on the transaction if not the same as the supplier.
43 |
# File 'lib/generated/gobl/bill/ordering.rb', line 43 property :seller, GOBL::Org::Party |
#tender ⇒ Array<GOBL::Org::DocumentRef> (readonly)
Tender advice, the identification of the call for tender or lot the invoice relates to.
83 |
# File 'lib/generated/gobl/bill/ordering.rb', line 83 property :tender, [GOBL::Org::DocumentRef] |